@@ -12,7 +12,10 @@ import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-cdk/aws-iot1click", "1.92.0", __name__[0:-6], "aws-iot1click@1.92.0.jsii.tgz"
+    "@aws-cdk/aws-iot1click",
+    "1.103.0",
+    __name__[0:-6],
+    "aws-iot1click@1.103.0.jsii.tgz",
 )
 
 __all__ = [
